==> spotbugs-maven-plugin-3.1.3.1-sources.jar: org/codehaus/mojo/spotbugs/SpotBugsGui.java <==
package org.codehaus.mojo.spotbugs;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@org.apache.maven.plugins.annotations.Mojo(name="gui", requiresDependencyResolution=org.apache.maven.plugins.annotations.ResolutionScope.TEST, requiresProject=true) public class SpotBugsGui
  extends org.apache.maven.plugin.AbstractMojo  implements
    org.codehaus.mojo.spotbugs.SpotBugsPluginsTrait,    groovy.lang.GroovyObject {
;
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.util.Locale getLocale() { return (java.util.Locale)null;}
public static  void setLocale(java.util.Locale value) { }
public  java.io.File getClassFilesDirectory() { return (java.io.File)null;}
public  void setClassFilesDirectory(java.io.File value) { }
public  java.lang.Boolean getDebug() { return (java.lang.Boolean)null;}
public  void setDebug(java.lang.Boolean value) { }
public  java.util.List getPluginArtifacts() { return (java.util.List)null;}
public  void setPluginArtifacts(java.util.List value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.String getPluginList() { return (java.lang.String)null;}
public  void setPluginList(java.lang.String value) { }
public  org.codehaus.mojo.spotbugs.PluginArtifact[] getPlugins() { return (org.codehaus.mojo.spotbugs.PluginArtifact[])null;}
public  void setPlugins(org.codehaus.mojo.spotbugs.PluginArtifact... value) { }
public  org.apache.maven.artifact.resolver.ArtifactResolver getArtifactResolver() { return (org.apache.maven.artifact.resolver.ArtifactResolver)null;}
public  void setArtifactResolver(org.apache.maven.artifact.resolver.ArtifactResolver value) { }
public  org.apache.maven.repository.RepositorySystem getFactory() { return (org.apache.maven.repository.RepositorySystem)null;}
public  void setFactory(org.apache.maven.repository.RepositorySystem value) { }
public  java.util.List getRemoteRepositories() { return (java.util.List)null;}
public  void setRemoteRepositories(java.util.List value) { }
public  org.apache.maven.artifact.repository.ArtifactRepository getLocalRepository() { return (org.apache.maven.artifact.repository.ArtifactRepository)null;}
public  void setLocalRepository(org.apache.maven.artifact.repository.ArtifactRepository value) { }
public  org.apache.maven.project.MavenProject getProject() { return (org.apache.maven.project.MavenProject)null;}
public  void setProject(org.apache.maven.project.MavenProject value) { }
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  java.io.File getSpotbugsXmlOutputDirectory() { return (java.io.File)null;}
public  void setSpotbugsXmlOutputDirectory(java.io.File value) { }
public  java.lang.String getEncoding() { return (java.lang.String)null;}
public  void setEncoding(java.lang.String value) { }
public  int getMaxHeap() { return (int)0;}
public  void setMaxHeap(int value) { }
public  org.codehaus.plexus.resource.ResourceManager getResourceManager() { return (org.codehaus.plexus.resource.ResourceManager)null;}
public  void setResourceManager(org.codehaus.plexus.resource.ResourceManager value) { }
public  void execute() { }
public  java.lang.String getSpotbugsPlugins() { return (java.lang.String)null;}
public  java.lang.String getEffortParameter() { return (java.lang.String)null;}
}

==> spotbugs-maven-plugin-4.5.3.0-sources.jar: org/codehaus/mojo/spotbugs/SpotBugsGui.java <==
package org.codehaus.mojo.spotbugs;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;

@org.apache.maven.plugins.annotations.Mojo(name="gui", requiresDependencyResolution=org.apache.maven.plugins.annotations.ResolutionScope.TEST, requiresProject=true) public class SpotBugsGui
  extends org.apache.maven.plugin.AbstractMojo  implements
    org.codehaus.mojo.spotbugs.SpotBugsPluginsTrait,    groovy.lang.GroovyObject {
;
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.util.Locale getLocale() { return (java.util.Locale)null;}
public static  void setLocale(java.util.Locale value) { }
public  java.io.File getClassFilesDirectory() { return (java.io.File)null;}
public  void setClassFilesDirectory(java.io.File value) { }
public  java.lang.Boolean getDebug() { return (java.lang.Boolean)null;}
public  java.lang.Boolean isDebug() { return (java.lang.Boolean)null;}
public  void setDebug(java.lang.Boolean value) { }
public  java.util.List getPluginArtifacts() { return (java.util.List)null;}
public  void setPluginArtifacts(java.util.List value) { }
public  java.lang.String getEffort() { return (java.lang.String)null;}
public  void setEffort(java.lang.String value) { }
public  java.lang.String getPluginList() { return (java.lang.String)null;}
public  void setPluginList(java.lang.String value) { }
public  org.codehaus.mojo.spotbugs.PluginArtifact[] getPlugins() { return (org.codehaus.mojo.spotbugs.PluginArtifact[])null;}
public  void setPlugins(org.codehaus.mojo.spotbugs.PluginArtifact... value) { }
public  org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver getArtifactResolver() { return (org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver)null;}
public  void setArtifactResolver(org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver value) { }
public  org.apache.maven.repository.RepositorySystem getFactory() { return (org.apache.maven.repository.RepositorySystem)null;}
public  void setFactory(org.apache.maven.repository.RepositorySystem value) { }
public  java.util.List getRemoteRepositories() { return (java.util.List)null;}
public  void setRemoteRepositories(java.util.List value) { }
public  org.apache.maven.artifact.repository.ArtifactRepository getLocalRepository() { return (org.apache.maven.artifact.repository.ArtifactRepository)null;}
public  void setLocalRepository(org.apache.maven.artifact.repository.ArtifactRepository value) { }
public  org.apache.maven.execution.MavenSession getSession() { return (org.apache.maven.execution.MavenSession)null;}
public  void setSession(org.apache.maven.execution.MavenSession value) { }
public  org.apache.maven.project.MavenProject getProject() { return (org.apache.maven.project.MavenProject)null;}
public  void setProject(org.apache.maven.project.MavenProject value) { }
public  java.util.ResourceBundle getBundle() { return (java.util.ResourceBundle)null;}
public  void setBundle(java.util.ResourceBundle value) { }
public  java.io.File getSpotbugsXmlOutputDirectory() { return (java.io.File)null;}
public  void setSpotbugsXmlOutputDirectory(java.io.File value) { }
public  java.lang.String getSpotbugsXmlOutputFilename() { return (java.lang.String)null;}
public  void setSpotbugsXmlOutputFilename(java.lang.String value) { }
public  java.lang.String getEncoding() { return (java.lang.String)null;}
public  void setEncoding(java.lang.String value) { }
public  int getMaxHeap() { return (int)0;}
public  void setMaxHeap(int value) { }
public  org.codehaus.plexus.resource.ResourceManager getResourceManager() { return (org.codehaus.plexus.resource.ResourceManager)null;}
public  void setResourceManager(org.codehaus.plexus.resource.ResourceManager value) { }
@java.lang.Override() public  void execute() { }
public  java.lang.String getSpotbugsPlugins() { return (java.lang.String)null;}
public  java.lang.String getEffortParameter() { return (java.lang.String)null;}
}
